/*
This file is part of the Juju GUI, which lets users view and manage Juju
environments within a graphical interface (https://launchpad.net/juju-gui).
Copyright (C) 2016 Canonical Ltd.

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU Affero General Public License version 3, as published by
the Free Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranties of MERCHANTABILITY,
SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero
General Public License for more details.

You should have received a copy of the GNU Affero General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

'use strict';

var juju = { components: {} }; // eslint-disable-line no-unused-vars

chai.config.includeStack = true;
chai.config.truncateThreshold = 0;

describe('DeploymentSignup', function () {

  beforeAll(function (done) {
    // By loading this file it adds the component to the juju components.
    YUI().use('deployment-signup', function () {
      done();
    });
  });

  it('can render', function () {
    const changeState = sinon.stub();
    const exportEnvironmentFile = sinon.stub();
    const renderer = jsTestUtils.shallowRender(React.createElement(
      juju.components.DeploymentSignup,
      {
        changeState: changeState,
        exportEnvironmentFile: exportEnvironmentFile,
        modelName: 'Prawns on the barbie' },
      React.createElement(
        'span',
        null,
        'content'
      )
    ), true);
    var instance = renderer.getMountedInstance();
    var output = renderer.getRenderOutput();
    const expected = React.createElement(
      juju.components.DeploymentPanel,
      {
        changeState: changeState,
        title: 'Prawns on the barbie' },
      React.createElement(
        'div',
        { className: 'deployment-signup' },
        React.createElement(
          'div',
          { className: 'six-col' },
          React.createElement(
            'h2',
            null,
            'Install Juju to deploy locally'
          ),
          React.createElement(
            'p',
            null,
            'Doing so provides on LXD, which allows you to recreate the production deployment environment on your own machine. This minimises portability issues when deploying to a public cloud, OpenStack or bare metal.'
          ),
          React.createElement(
            'p',
            null,
            'To deploy locally:'
          ),
          React.createElement(
            'ol',
            null,
            React.createElement(
              'li',
              null,
              React.createElement(juju.components.GenericButton, {
                action: exportEnvironmentFile,
                type: 'base',
                title: 'Download your model' })
            ),
            React.createElement(
              'li',
              null,
              React.createElement(
                'a',
                { href: 'https://jujucharms.com/docs/stable/getting-started',
                  target: '_blank' },
                'Install Juju'
              )
            ),
            React.createElement(
              'li',
              null,
              'Add your model to deploy'
            )
          ),
          React.createElement(
            'p',
            null,
            'Or continue to the\xA0',
            React.createElement(juju.components.GenericButton, {
              action: instance._displayFlow,
              type: 'inline-neutral',
              title: 'deployment demo of Juju' })
          )
        ),
        React.createElement(
          'div',
          { className: 'twelve-col' },
          React.createElement(
            'h2',
            null,
            'Lorem ipsum dolor sit'
          ),
          React.createElement(
            'p',
            { className: 'six-col' },
            'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.'
          ),
          React.createElement(
            'ul',
            null,
            React.createElement(
              'li',
              { className: 'six-col' },
              'Lorem ipsum'
            ),
            React.createElement(
              'li',
              { className: 'six-col last-col' },
              'Onsectetur adipisicing elit'
            ),
            React.createElement(
              'li',
              { className: 'six-col' },
              'Sed do eiusmod'
            ),
            React.createElement(
              'li',
              { className: 'six-col last-col' },
              'Tempor incididunt ut'
            ),
            React.createElement(
              'li',
              { className: 'six-col' },
              'Labore et dolore magna aliqua'
            )
          ),
          React.createElement(
            'form',
            { className: 'twelve-col' },
            React.createElement(juju.components.GenericInput, {
              label: 'Lorem ipsum dolor',
              required: true,
              ref: 'email',
              validate: [{
                regex: /\S+/,
                error: 'This field is required.'
              }],
              value: '' }),
            React.createElement(juju.components.GenericButton, {
              action: instance._handleSignup,
              type: 'inline-positive',
              submit: true,
              title: 'Lorem ipsum' })
          )
        )
      )
    );
    assert.deepEqual(output, expected);
  });

  it('can navigate to the flow view', function () {
    const changeState = sinon.stub();
    const output = jsTestUtils.shallowRender(React.createElement(
      juju.components.DeploymentSignup,
      {
        changeState: changeState,
        exportEnvironmentFile: sinon.stub(),
        modelName: 'Lamington' },
      React.createElement(
        'span',
        null,
        'content'
      )
    ));
    output.props.children.props.children[0].props.children[4].props.children[1].props.action();
    assert.equal(changeState.callCount, 1);
    assert.deepEqual(changeState.args[0][0], {
      sectionC: {
        component: 'deploy',
        metadata: {
          activeComponent: 'flow'
        }
      }
    });
  });

  it('can export the model', function () {
    const exportEnvironmentFile = sinon.stub();
    const output = jsTestUtils.shallowRender(React.createElement(
      juju.components.DeploymentSignup,
      {
        changeState: sinon.stub(),
        exportEnvironmentFile: exportEnvironmentFile,
        modelName: 'Lamington' },
      React.createElement(
        'span',
        null,
        'content'
      )
    ));
    output.props.children.props.children[0].props.children[3].props.children[0].props.children.props.action();
    assert.equal(exportEnvironmentFile.callCount, 1);
  });
});